Calculates the proximal L1 mapping for the given input matrix
prox.l1(z, lambda, r)
proximal L1 Mapping
input matrix
parameters for calculating proximal L1 mapping
number of columns used in matrix
Shixiang Chen, Justin Huang, Benjamin Jochem, Shiqian Ma, Lingzhou Xue and Hui Zou
Chen, S., Ma, S., Xue, L., and Zou, H. (2020) "An Alternating Manifold Proximal Gradient Method for Sparse Principal Component Analysis and Sparse Canonical Correlation Analysis" *INFORMS Journal on Optimization* 2:3, 192-208